clarifi_prep: Prep Exported Data from Clarifi

Description Usage Arguments Value

View source: R/clarifi_prep.R

Description

Prep Exported Data from Clarifi

Usage

1
clarifi_prep(clarifi_data, type = c("fundamental", "price"))

Arguments

clarifi_data

Clarifi exported data read into a data.frame. Should have date,sector,ticker, and quarterly indicator in first four columns in that order, followed by any order of fundamental metrics. For pricing data, should have date, ticker, high, low, close, volume, dividends per share, and market capitalization.

type

type of export data either "fundamental" or "price"

Value

environment variable for fundamental or pricing data.


WillPalmquist/PortfolioMgmt documentation built on June 10, 2021, 10:35 p.m.