Description Usage Arguments Value
Prep Exported Data from Clarifi
1 | clarifi_prep(clarifi_data, type = c("fundamental", "price"))
|
clarifi_data |
Clarifi exported data read into a data.frame. Should have date,sector,ticker, and quarterly indicator in first four columns in that order, followed by any order of fundamental metrics. For pricing data, should have date, ticker, high, low, close, volume, dividends per share, and market capitalization. |
type |
type of export data either "fundamental" or "price" |
environment variable for fundamental or pricing data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.